==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/stackdriver/ServiceAccountPathCredsFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.stackdriver;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ServiceAccountPathCredsFluentImpl<A extends ServiceAccountPathCredsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ServiceAccountPathCredsFluent<A>{

    private String serviceAccountPath;

    public ServiceAccountPathCredsFluentImpl(){
    }
    public ServiceAccountPathCredsFluentImpl(ServiceAccountPathCreds instance){
            this.withServiceAccountPath(instance.getServiceAccountPath()); 
    }

    public String getServiceAccountPath(){
            return this.serviceAccountPath;
    }

    public A withServiceAccountPath(String serviceAccountPath){
            this.serviceAccountPath=serviceAccountPath; return (A) this;
    }

    public Boolean hasServiceAccountPath(){
            return this.serviceAccountPath != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ServiceAccountPathCredsFluentImpl that = (ServiceAccountPathCredsFluentImpl) o;
            if (serviceAccountPath != null ? !serviceAccountPath.equals(that.serviceAccountPath) :that.serviceAccountPath != null) return false;
            return true;
    }




}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/stackdriver/ServiceAccountPathCredsFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.stackdriver;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ServiceAccountPathCredsFluentImpl<A extends ServiceAccountPathCredsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ServiceAccountPathCredsFluent<A>{

    private String serviceAccountPath;

    public ServiceAccountPathCredsFluentImpl(){
    }
    public ServiceAccountPathCredsFluentImpl(ServiceAccountPathCreds instance){
            this.withServiceAccountPath(instance.getServiceAccountPath()); 
    }

    public String getServiceAccountPath(){
            return this.serviceAccountPath;
    }

    public A withServiceAccountPath(String serviceAccountPath){
            this.serviceAccountPath=serviceAccountPath; return (A) this;
    }

    public Boolean hasServiceAccountPath(){
            return this.serviceAccountPath != null;
    }

    public A withNewServiceAccountPath(String arg1){
            return (A)withServiceAccountPath(new String(arg1));
    }

    public A withNewServiceAccountPath(StringBuilder arg1){
            return (A)withServiceAccountPath(new String(arg1));
    }

    public A withNewServiceAccountPath(StringBuffer arg1){
            return (A)withServiceAccountPath(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ServiceAccountPathCredsFluentImpl that = (ServiceAccountPathCredsFluentImpl) o;
            if (serviceAccountPath != null ? !serviceAccountPath.equals(that.serviceAccountPath) :that.serviceAccountPath != null) return false;
            return true;
    }




}
